@@ -7,6 +7,8 @@
 """
 import logging
 
+LOG = logging.getLogger("tornado.general")
+
 # TODO: Add support for ujson module once they can accept unicode strings
 
 # Try to find best json encoder available
@@ -18,12 +20,12 @@ try:
     json_decode = lambda data: simplejson.loads(data)
     JSONDecodeError = ValueError
 
-    logging.debug('sockjs.tornado will use simplejson module')
+    LOG.debug('sockjs.tornado will use simplejson module')
 except ImportError:
     # Use slow json
     import json
 
-    logging.debug('sockjs.tornado will use json module')
+    LOG.debug('sockjs.tornado will use json module')
 
     json_encode = lambda data: json.dumps(data, separators=(',', ':'))
     json_decode = lambda data: json.loads(data)
